@@ -35,17 +35,23 @@ def describe_directory(directory, ignore_git=True):
                             signature = ast.unparse(node.args)
                             if ast.get_docstring(node) != None:
                                 docstring = _clean_output(ast.get_docstring(node))
+                            else:
+                                docstring = ""
                             functions.update(
                                 {node.name.replace(" ", "") + "(" + signature.replace(" ", "") + ")": docstring})
                         elif isinstance(node, ast.ClassDef):
                             if ast.get_docstring(node) != None:
                                 docstring = _clean_output(ast.get_docstring(node))
+                            else:
+                                docstring = ""
                             methods = {}
                             for method in node.body:
                                 if isinstance(method, ast.FunctionDef):
                                     signature = ast.unparse(method.args)
                                     if ast.get_docstring(method) != None:
                                         docstring = _clean_output(ast.get_docstring(method))
+                                    else:
+                                        docstring = ""
                                     methods.update({method.name.replace(" ", "") + "(" + signature.replace(" ",
                                                "") + ")": docstring})
                             classes.update({node.name.replace(" ", ""): {"methods": methods}})
